@@ -13,7 +13,7 @@ def main():
                         action='store_true')
     args = parser.parse_args()
     if args.version:
-        print("Current client version: v0.1.5")
+        print("Current client version: v0.1.7")
     if args.demo:
         x_sweetest_dir = Path(__file__).resolve().parents[0]
         example_dir = x_sweetest_dir / 'example' / 'x_sweetest_example.zip'
@@ -21,7 +21,7 @@ def main():
         print('Generated `x_sweetest_example` successfully\n' +
               'Quick experience, please enter the following command ' +
               '(go to the sample directory and start running the script):\n\n' +
-              'cd x_sweetest_example\npython start.py')
+              'cd x_sweetest_example\npython echo.py')
 
 
 def extract(z_file, path):
